---
name: Documentation or tutorial request
about: Suggest an idea to improve documentation and/or tutorials
title: ''
labels: 'documentation'
assignees: ''

---

**Is an existing functionality incorrectly or not sufficiently described in the documentation?**
A clear and concise description of what the problem is.

**Do you have trouble getting a tutorial up and running?**
A clear and concise description of what fails

**Suggest an improvement**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.
